@@ -47,6 +47,17 @@ case "$1" in
 
         chown $WWW_USER "$VAR_DIR/$USER_DB"
         chmod u=rw,g=r,o= "$VAR_DIR/$USER_DB"
+
+        if [ -e /usr/share/apache2/apache2-maintscript-helper ];then
+            # Debian Jessie / Apache2.4
+            mkdir -p /etc/apache2/conf-available
+            ln -sf /etc/benno-web/apache-2.4.conf /etc/apache2/conf-available/benno.conf
+            . /usr/share/apache2/apache2-maintscript-helper
+            apache2_invoke enconf benno
+        elif [ ! -f /etc/apache2/conf.d/benno ];then
+            mkdir -p /etc/apache2/conf.d
+            ln -sf /etc/benno-web/apache-2.2.conf /etc/apache2/conf.d/benno
+        fi
     ;;
 
     abort-upgrade|abort-remove|abort-deconfigure)
