@@ -310,40 +310,43 @@ class Application extends ApplicationConfig
         elseif ($this->getSession('SKIN')) {
             $this->skin = $this->getSession('SKIN');
         }
-        else {
-            $this->skin = $this->lang;
-        }
 
         // Template initialization
         $this->TPL = new Smarty;
         $this->TPL->compile_check = true;
 
         if(array_key_exists('TEMPLATE_ROOT',$this->config)) {
-            $root_dir = getcwd().'/'.$this->config['TEMPLATE_ROOT'];
+            $tpl_root = getcwd().'/'.$this->config['TEMPLATE_ROOT'].'/templates';
         }
         else {
-            $root_dir = getcwd();
+            $tpl_root = getcwd().'/templates';
         }
 
-        $skin_dir = $root_dir.'/'.$this->module.'/templates/'.$this->skin;
-        if (! is_dir($skin_dir)) {
-            $skin_dir = $root_dir.'/'.$this->module.'/templates/'.$default_locale;
+        if ($this->skin) {
+            $skin_dir = $tpl_root.'/'.$this->skin;
+        }
+        // fallback
+        if (! is_file($skin_dir.'/header.tpl')) {
+            $skin_dir = $tpl_root.'/default';
         }
         $this->TPL->template_dir = $skin_dir;
 
-        $message_file = $skin_dir.'.msg';
+        $message_file = $tpl_root.'/'.$this->lang.'.msg';
         if (! is_readable($message_file)) {
-            $message_file = $skin_dir.'/'.$default_locale.'.msg';
+            $message_file = $tpl_root.'/'.$default_locale.'.msg';
+        }
+
+        // skin localization
+        $locale_text = $tpl_root.'/'.$this->lang.'.txt';
+        if (! is_readable($locale_text)) {
+            $locale_text = $tpl_root.'/'.$default_locale.'.txt';
         }
 
         // messages from file
         $this->message_file = $message_file;
         $this->Error = new ApplicationError ($message_file);
 
-
-        if ($this->DEBUG) {
-            $this->log('[SPAF2/Application]:template_dir '.$skin_dir);
-        }
+        $this->log('template_dir '.$skin_dir,2,'SPAF2/App');
         $templates_cache_base = $this->getConfig('TEMPLATE_CACHE');
         $templates_cache_skin = $templates_cache_base.'/'.$this->skin;
         if (!is_dir($templates_cache_skin)) {
@@ -353,11 +356,12 @@ class Application extends ApplicationConfig
             $this->TPL->compile_dir = $templates_cache_skin;
         }
         else {
-            $this->log('WARNING: Cannot write to templates cache: '.$templates_cache_skin);
+            $this->log('WARNING: Cannot write to templates cache: '.$templates_cache_skin,0,'SPAF2/App');
             $this->TPL->compile_dir = '/tmp';
         }
         $this->TPL->config_dir   = $this->configdir;
-        $this->TPL->cache_dir    = $root_dir . '/cache';
+        $this->TPL->cache_dir    = $tpl_root . '/cache';
+        $this->TPL->assign('LOCALE_TEXT',$locale_text);
         $this->TPL->assign('SN',session_name());
         $this->TPL->assign('SID',session_id());
         $this->TPL->assign('CA',$this->getParam('CA'));
@@ -433,13 +437,17 @@ class Application extends ApplicationConfig
      *
      * @access public
      * @param string $parameter
+     * @param string $default (optional)
      * @return misc $value
      */
-    function getConfig($parameter)
+    function getConfig($parameter,$default='')
     {
         if (isset($this->config[$parameter])) {
             return  $this->config[$parameter];
         }
+        else if ($default) {
+            return $default;
+        }
         else {
             return FALSE;
         }
@@ -504,7 +512,7 @@ class Application extends ApplicationConfig
             $this->_output .= ob_get_contents();
         }
         elseif(@$this->config['DEBUG'] > 0) {
-            $this->log("[SPAF2/Application] NO TEMPLATE $template");
+            $this->log("NO TEMPLATE $template",0,'SPAF2/App');
         }
         ob_end_clean();
     }
@@ -533,9 +541,18 @@ class Application extends ApplicationConfig
      * @access public
      * @param string $message
      */
-    function log ($message)
+    function log ($message,$threshold=0,$module='')
     {
-        error_log("[$this->view] $message");
+        $view = '-';
+        if ($this->view != '') {
+            $view = $this->view;
+        }
+        if ($module) {
+            $view = $module;
+        }
+        if ($this->DEBUG >= $threshold) {
+            error_log("[$threshold:$view] $message");
+        }
     }
 
 
@@ -713,8 +730,8 @@ class Application extends ApplicationConfig
             $params .= '&'. $plist;
         }
         if ($this->DEBUG) {
-            $this->log("[SPAF2/Application]:REDIRECT ===> $action");
-            $this->log("[SPAF2/Application] ------------------------------");
+            $this->log("REDIRECT ===> $action",2,'SPAF2/App');
+            $this->log("------------------------------------------",2,'SPAF2/App');
         }
 
         if ($redirect_base = $this->getConfig('REDIRECT_BASE')) {
@@ -724,7 +741,7 @@ class Application extends ApplicationConfig
             $PROTO = 'https://';
             $http_host = $_SERVER['HTTP_HOST'];
             if (!preg_match('/^[a-z\d:\.](-*[a-z\d:\.])*$/',$http_host)) {
-                $this->log('Exit while invalid hostname for redirect: '.$http_host);
+                $this->log('Exit while invalid hostname for redirect: '.$http_host,0,'SPAF2/App');
                 exit;
             }
             $location = 'Location: '.$PROTO.$http_host.$_SERVER['SCRIPT_NAME']."?$params";
@@ -733,7 +750,7 @@ class Application extends ApplicationConfig
             $PROTO = 'http://';
             $http_host = $_SERVER['HTTP_HOST'];
             if (!preg_match('/^[a-z\d:\.](-*[a-z\d:\.])*$/',$http_host)) {
-                $this->log('Exit while invalid hostname given for redirect: '.$http_host);
+                $this->log('Exit while invalid hostname given for redirect: '.$http_host,0,'SPAF2/App');
                 exit;
             }
             $location = 'Location: '.$PROTO.$http_host.$_SERVER['SCRIPT_NAME']."?$params";
@@ -820,7 +837,7 @@ class Application extends ApplicationConfig
     {
         $msg_string = '';
         if (! $fd = @fopen ($this->message_file, "r")) {
-	        $this->log('ERROR: Cannot read message file '.$this->message_file);
+	        $this->log('ERROR: Cannot read message file '.$this->message_file,0,'SPAF2/App');
         }
         else {
             while (!feof ($fd)) {
@@ -874,7 +891,7 @@ class Application extends ApplicationConfig
      * @param string $error symbol
      * @return $int error count
      */
-    function setError ($error='')
+    function setError ($error)
     {
         if ($error) {
             $count = $this->Error->setError($error);
@@ -1191,7 +1208,7 @@ class ApplicationError extends Application
             $notfound = 1;
         }
         if ($notfound == 1) {
-            $this->log("[SPAF2/Application] Undefined error sym: $error");
+            $this->log("Undefined error sym: $error",0,'SPAF2/App');
             $this->count = array_push($this->messages,$error);
         }
         return $this->count;
