@@ -52,22 +52,25 @@ if (! $pass) {
 
 $User = new User($userid);
 try {
-    if ($authscript) {
-        $User->loadExternal($authscript,$pass);
-    }
-    else {
+    $User->loadExternal($authscript,$pass);
+}
+catch (Exception $e) {
+    $exc = $e->getMessage();
+    if ($exc == 'ERR_EXECUTE') {
         $User->load();
         // check authentication
         if ($User->password != md5($pass)) {
-            throw new Exception('ERR_AUTH');
+            // Authentication error -> redirect to login
+            $App->log('Authentication of '.$User->id.' failed');
+            $App->redirect('default',array('MSG'=>'ERR_AUTH'));
         }
     }
+    else {
+        $App->log('Authentication error: '.$exc);
+        $App->redirect('default',array('MSG'=>$exc));
+    }
 }
-catch (Exception $e) {
-    // Authentication error -> redirect to login
-    $App->log('Authentication error.');
-    $App->redirect('default',array('MSG'=>$e->getMessage()));
-}
+$App->log('Authentication of '.$User->id. ' successful',1);
 // LOGIN SUCCESSFUL
 
 // initialize backend
