@@ -56,21 +56,16 @@ try {
     $QueryResult = $Backend->query($ExtQuery,0,$search_limit);
     if ($QueryResult->found == 0) {
         $App->setMsg('MSG_NOTFOUND');
-    }
-    $sessionMailId = $QueryResult->getSessionMailId(0);
-    $EMail = $Backend->fetch($sessionMailId);       // show first mail
-    $displayedMailId = $sessionMailId;
-    $App->setSession('displayedMailId',$displayedMailId);
-}
-catch (Exception $e) {
-    if ($e->getMessage() == 'ID_NOT_FOUND') {
-        $EMail = '';
+        $sessionMailId = '';
     }
     else {
-        $App->log('[searchExt] '.$e->getMessage());
-        $App->setMsg($e->getMessage());
+        $sessionMailId = $QueryResult->getSessionMailId(0);
     }
 }
+catch (Exception $e) {
+    $App->log('[searchExt] '.$e->getMessage());
+    $App->setMsg($e->getMessage());
+}
 
 $App->view = 'showList';
 
