@@ -52,15 +52,14 @@ try {
     $QueryResult = $Backend->query($SimpleQuery,0,$search_limit);
     if ($QueryResult->found == 0) {
         $App->setMsg('MSG_NOTFOUND');
+        $sessionMailId = '';
+    }
+    else {
+        $sessionMailId = $QueryResult->getSessionMailId(0);
     }
-    $sessionMailId = $QueryResult->getSessionMailId(0);
-    $EMail = $Backend->fetch($sessionMailId);       // show first mail
-    $displayedMailId = $sessionMailId;
-    $App->setSession('displayedMailId',$displayedMailId);
 }
 catch (Exception $e) {
     if ($e->getMessage() == 'ID_NOT_FOUND') {
-        $EMail = '';
         $App->view = 'showList';
     }
     else {
