@@ -144,11 +144,13 @@ class Backend
      * @param string $mailId
      * @return object $EMail
      */
-    function fetchAttachment ($mailId,$filename)
+    function fetchAttachment ($sessionMailId,$filename)
     {
+        $bennoId = QueryResult::getBennoId($sessionMailId);
+
         $request_url  = $this->base_url.'/attachment/';
         $query_string = 'archive='.$this->archive.
-                        '&id='.$mailId.
+                        '&id='.$bennoId.
                         '&attachment='.$filename;
 
         $file = $this->_curl_query($request_url,$query_string,'raw');
@@ -176,7 +178,8 @@ class Backend
         if (! $data) {
             $App->log('[Backend/fetchLicense] No valid License found');
         }
-        $License = new License($data['licenseFile'],$data['licenseValid']);
+
+        $License = new License($data['licenseStatus'],$data['licenseExpires'],$data['licenseType'],$data['licenseFile']);
 
         return $License;
     }
@@ -210,7 +213,7 @@ class Backend
 
         $resultList = $this->_curl_query($request_url,$query);
 
-        if ($resultList['licenseValid'] != 1) {
+        if (! preg_match('/^LICENSE_VALID/',$resultList['licenseValid'])) {
             if ($App->getConfig('USERPERMISSONS') != 'DISABLED') {
                 $App->setMsg('LICENSE_ERROR');
                 throw new Exception('LICENSE_ERROR');
@@ -265,7 +268,7 @@ class Backend
         $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE); 
         if ($httpCode != 200) {
             $App->log('[Backend/query] HTTP error: '.$httpCode);
-            throw new Exception('ERR_HTTP_'.$httpCode);
+            throw new Exception('ERR_REST_'.$httpCode);
         }
 
         // split header / body
