@@ -36,7 +36,7 @@
 class DateConvert
 {
 
-    function DateDiff ($before)
+    public static function DateDiff ($before)
     {
         /**
          * Returns an array first and last timestamp for time differences
@@ -73,7 +73,7 @@ class DateConvert
     /**
      * Converts a date (dd.mm.yyyy) to timestamp
      */
-    function Date2Timestamp ($date,$date_format)
+    public static function Date2Timestamp ($date,$date_format)
     {
         $timestamp = '';
         if ($date !== '') {
@@ -92,7 +92,7 @@ class DateConvert
     /**
      * Return current date (dd.mm.YYYY) of timestamp
      */
-    function Timestamp2Date ($timestamp)
+    public static function Timestamp2Date ($timestamp)
     {
         return strftime('%d.%m.%Y',$timestamp);
     }
