@@ -38,12 +38,15 @@ class EMail
     var $id;
     var $bennoId;
     var $from;
-
-    // array
     var $to;
     var $cc;
     var $bcc;
 
+    // array
+    var $_lto;
+    var $_lcc;
+    var $_lbcc;
+
     var $subject;
     var $date;
     var $size;
@@ -58,9 +61,12 @@ class EMail
         $this->id       = $id; 
         $this->bennoId  = $bennoId; 
         $this->from     = $from;
-        $this->to       = $to;
-        $this->cc       = $cc;
-        $this->bcc      = $bcc;
+        $this->_lto     = $to;
+        $this->_lcc     = $cc;
+        $this->_lbcc    = $bcc;
+        $this->to       = $this->getTo();
+        $this->cc       = $this->getCc();
+        $this->bcc      = $this->getBcc();
         $this->subject  = $subject;
         if ( !is_numeric($date) )
             $this->date = $date;
@@ -105,7 +111,7 @@ class EMail
      */
     function getSubject()
     {
-        return htmlentities($this->subject,ENT_COMPAT | ENT_HTML401,'UTF-8');
+        return $this->subject;
     }
 
 
@@ -118,7 +124,7 @@ class EMail
     function getTo ()
     {
         $return = '';
-        foreach ($this->to as $value) {
+        foreach ($this->_lto as $value) {
             $return .= $value.' ';
         }
         return $return;
@@ -134,7 +140,7 @@ class EMail
     function getCc ()
     {
         $return = '';
-        foreach ($this->cc as $value) {
+        foreach ($this->_lcc as $value) {
             $return .= $value.' ';
         }
         return $return;
@@ -150,7 +156,7 @@ class EMail
     function getBcc ()
     {
         $return = '';
-        foreach ($this->bcc as $value) {
+        foreach ($this->_lbcc as $value) {
             $return .= $value.' ';
         }
         return $return;
@@ -195,7 +201,11 @@ class EMail
                 }
                 // Content-Type == text/plain
                 if (stripos($partContentType,'text/plain') !== false) {
-                    $body['text/plain'] .= $bodypart['data']."\n";
+
+                    // unconverted html could break user interface
+                    // ... <base href="$external_site" >
+                    $body['text/plain'] .= htmlspecialchars($bodypart['data'],ENT_COMPAT | ENT_HTML401,'UTF-8')."\n";
+
                     // second body part text/plain contains normally disclaimer
                     if ($count['text/plain'] == 1) {    // disclaimer part
                         $Attachment = new Attachment('content.disclaimer',$partContentType,0,false);
@@ -222,7 +232,16 @@ class EMail
                 throw new Exception('CONTENT_UNKNOWN');
             }
         }                               // text/plain
-        return htmlentities($content,ENT_COMPAT | ENT_HTML401,'UTF-8');
+        return $content;
+    }
+
+
+    /**
+     * Return array with attachments
+     */
+    function getAttachments()
+    {
+        return $this->attachments;
     }
 
 
