@@ -112,9 +112,7 @@ class QueryResult
     {
         global $App;
         if (!isset($this->mailList[$resultnum])) {
-            if ($App->DEBUG) {
-                $App->log("Email object with result id $resultnum not defined");
-            }
+            $App->log("Email object with result id $resultnum not defined",1);
             throw new Exception("ID_NOT_FOUND");
         }
         return $this->mailList[$resultnum]->id;
@@ -175,15 +173,13 @@ class QueryResult
      * @param string $sessionMailId
      * @return string $bennoId
      */
-    function getBennoId($sessionMailId)
+    public static function getBennoId($sessionMailId)
     {
         global $App;
         $bennoIdTable = $App->getSession('bennoIdTable');
         $bennoId = array_search($sessionMailId,$bennoIdTable);
         if ($bennoId == false) {
-            if ($App->DEBUG) {
-                $App->log("Email object with sessionMailId $sessionMailId not defined");
-            }
+            $App->log("Email object with sessionMailId $sessionMailId not defined",1);
             throw new Exception("ID_NOT_FOUND");
         }
         return $bennoId;
