@@ -34,4 +34,15 @@
 // set language version for template (datepicker localization)
 $App->assign('LANG',$App->lang);
 
+switch ($App->lang) {
+    case 'en':
+        $LOCALE['timeformat'] = '%H:%M';
+        $LOCALE['dateformat'] = '%m/%d/%Y';
+        break;
+    default:
+        $LOCALE['timeformat'] = '%H:%M';
+        $LOCALE['dateformat'] = '%d.%m.%Y';
+}
+
+
 ?>
