@@ -34,7 +34,7 @@ $request = $_SERVER['PATH_INFO'];       // /search/ or /mail/
 
 // Authentication
 if (! $passwd) {
-    $App->log('No password given.');
+    $App->log('No password given.',1);
     authentication_required('NO PASSWORD GIVEN');
 }
 
