@@ -49,34 +49,24 @@ $App->assign('Backend',$Backend);
 if ($QueryResult) {
     $App->assign('MailList',$QueryResult->fetchMails());
 }
-try {
-    if ($EMail) { // EMail object may not be defined
-        $App->assign('EMail',$EMail);
-        $EMailBody = $EMail->getBody('text/plain');
-        $App->assign('EMailBody',$EMailBody);
-        $App->assign('EMailBodyTemplate','showContentText.tpl');
-    }
-}
-catch (Exception $e) {
-    $ExceptionMessage = $e->getMessage();
-    if ($ExceptionMessage == 'CONTENT_HTML') {
-        $App->assign('EMailBodyTemplate','showContentHtml.tpl');
-    }
-    else {
-        $App->assign('EMailBodyTemplate','showContentUnknown.tpl');
-    }
-}
+
+$DummyMail = new EMail('dummy','dummy');
+$App->assign('EMail',$DummyMail);
+$App->assign('EMailBodyTemplate','showContentText.tpl');
 
 $App->assign('search_limit',$search_limit);
 $App->assign('timeslice',$timeslice);
 
 $App->assign('sortOrder',$sortOrder);
 
-if (isset($displayedMailId))
-    $App->assign('displayedMailId',$displayedMailId);
+$App->assign('show_greeting',$show_greeting);
+$App->assign('DATEPICKER_POPUP',$App->getConfig('DATEPICKER_POPUP','both'));
+
+
+// load mail in content area
+$App->assign('currentMailId',$sessionMailId);
 
 if (isset($queryId)) // display current stored query
     $App->assign('queryId',$queryId);
 
-
 ?>
